spacepy.data_assimilation.addmodelerror_old — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »

# spacepy.data_assimilation.addmodelerror_old

`spacepy.data_assimilation.` `addmodelerror_old`(dd, A, y, L)

  this routine will add a standard error to the ensemble states

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »